@@ -89,9 +89,28 @@ test_that("Dic downloading works", {
   expect_warning(get_eurostat_dic("na_item"), NA)
 })
 
+test_that("Factors are retained in data.frame", {
+  skip_on_cran()
+  y <- label_eurostat(data.frame(unit = factor("EUR")))
+  expect_is(y$unit, "factor")
+})
+
+test_that("Duplicated gives an error", {
+  skip_on_cran()
+  expect_error(label_eurostat(x = factor(c("P5G", "P5")), dic = "na_item"))
+})
+
+test_that("Duplicated with fix_duplicated does not give an error", {
+  skip_on_cran()
+  expect_match(as.character(
+    label_eurostat(x = factor(c("P5G", "P5")), dic = "na_item", 
+                              fix_duplicated = TRUE)), "P5", all = TRUE)
+})
 
 context("Flags")
 
+flag_dat <- get_eurostat("tsdtr210", type = "label", keepFlags=T, cache = FALSE)
+
 test_that("get_eurostat includes flags",{
   skip_on_cran()
   expect_true(all(c("flags") %in%
@@ -101,13 +120,13 @@ test_that("get_eurostat includes flags",{
 test_that("keepFlags + label as in #61",{
   skip_on_cran()
   expect_true(all(c("flags") %in%
-                    names(get_eurostat("tsdtr210", type = "label", keepFlags=T))))
+                    names(flag_dat)))
 })
 
-test_that("flags contain some confidential flagged fields",{
+test_that("flag content",{
   skip_on_cran()
-  expect_true(c("c") %in%
-              unique(get_eurostat("naio_10_cp1620", keepFlags = TRUE)$flags))
+  expect_true(all(c("b", "be") %in%
+              unique(flag_dat$flags)))
 })
 
 context("json")
